Unified Judicial System of Pennsylvania: Superior Court Opinions

http://www.pacourts.us/assets/rss/SuperiorOpinionsRss.ashx Unified Judicial System of Pennsylvania: Superior Court Opinions Wed, 30 Jul 2014 04:00:00 GMT en-us Judgment List http://www.pacourts.us/assets/opinions/Superior/out/073014e.pdf http://www.pacourts.us/assets/opinions/Superior/out/073014e.pdf http://www.pacourts.us/assets/opinions/Superior/out/073014e.pdf Wed, 30 Jul 2014 04:00:00 GMT Judgment List http://www.pacourts.us/assets/opinions/Superior/out/073014m.pdf http://www.pacourts.us/assets/opinions/Superior/out/073014m.pdf http://www.pacourts.us/assets/opinions/Superior/out/073014m.pdf Wed, 30 Jul 2014 04:00:00 GMT Com. v. Chang, S. No. 3242 EDA 2012 http://www.pacourts.us/assets/opinions/Superior/out/J-A02016-14m - 1018917432462365.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A02016-14m - 1018917432462365.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A02016-14m - 1018917432462365.pdf Wed, 30 Jul 2014 04:00:00 GMT 14 Com. v. Lewis, D. No. 2172 EDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-S33022-14m - 1018917852462516.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S33022-14m - 1018917852462516.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S33022-14m - 1018917852462516.pdf Wed, 30 Jul 2014 04:00:00 GMT 13 Com. v. Mayes, N. No. 2020 EDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-S28026-14m.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S28026-14m.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S28026-14m.pdf Wed, 30 Jul 2014 04:00:00 GMT 11 Com. v. Fulton, L. No. 2168 EDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-S31023-14m - 1018917702462472.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S31023-14m - 1018917702462472.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S31023-14m - 1018917702462472.pdf Wed, 30 Jul 2014 04:00:00 GMT 9 Com. v. McDuffy, M. No. 2691 EDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-S31028-14m - 1018917962462531.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S31028-14m - 1018917962462531.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S31028-14m - 1018917962462531.pdf Wed, 30 Jul 2014 04:00:00 GMT 9 Com. v. Kerr, R. No. 149 EDA 2014 http://www.pacourts.us/assets/opinions/Superior/out/J-S38035-14m - 1018918032462555.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S38035-14m - 1018918032462555.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S38035-14m - 1018918032462555.pdf Wed, 30 Jul 2014 04:00:00 GMT 9 Com. v. Serrano-Torres, J. No. 1586 MDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-A14024-14m - 1018915732461899.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A14024-14m - 1018915732461899.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A14024-14m - 1018915732461899.pdf Wed, 30 Jul 2014 04:00:00 GMT 13 Judgment Lists http://www.pacourts.us/assets/opinions/Superior/out/072914e.pdf http://www.pacourts.us/assets/opinions/Superior/out/072914e.pdf http://www.pacourts.us/assets/opinions/Superior/out/072914e.pdf Tue, 29 Jul 2014 04:00:00 GMT Judgment Lists http://www.pacourts.us/assets/opinions/Superior/out/072914m.pdf http://www.pacourts.us/assets/opinions/Superior/out/072914m.pdf http://www.pacourts.us/assets/opinions/Superior/out/072914m.pdf Tue, 29 Jul 2014 04:00:00 GMT Judgment Lists http://www.pacourts.us/assets/opinions/Superior/out/072914w.pdf http://www.pacourts.us/assets/opinions/Superior/out/072914w.pdf http://www.pacourts.us/assets/opinions/Superior/out/072914w.pdf Tue, 29 Jul 2014 04:00:00 GMT Louis Dreyfus Comm. v. Financial Software Sys. No. 2816 EDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-A13032-14o - 1018904552457662.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A13032-14o - 1018904552457662.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A13032-14o - 1018904552457662.pdf Tue, 29 Jul 2014 04:00:00 GMT 17 Spitsin, I. v. WGM Trans. No. 2792 EDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-S23039-14o - 1018904532457650.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S23039-14o - 1018904532457650.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S23039-14o - 1018904532457650.pdf Tue, 29 Jul 2014 04:00:00 GMT 15 Pennsylvania Services Corp. v. Texas Eastern No. 1429 WDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-A16021-14o - 1018906982458195.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A16021-14o - 1018906982458195.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A16021-14o - 1018906982458195.pdf Tue, 29 Jul 2014 04:00:00 GMT 3 Pennsylvania Services Corp. v. Texas Eastern No. 1429 WDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-A16021-14cs - 1018906982458197.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A16021-14cs - 1018906982458197.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A16021-14cs - 1018906982458197.pdf Tue, 29 Jul 2014 04:00:00 GMT 14 Kozel, D. v. Kozel, D. No. 461 WDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-A01019-14o - 1018902052457090.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A01019-14o - 1018902052457090.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A01019-14o - 1018902052457090.pdf Tue, 29 Jul 2014 04:00:00 GMT 11 Perry, L. v. Perry, W. No. 363 EDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-A02020-14m.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A02020-14m.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A02020-14m.pdf Tue, 29 Jul 2014 04:00:00 GMT 14 Perry, L. v. Perry, W. No. 363 EDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-A02020-14cdm - 1018904922457764.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A02020-14cdm - 1018904922457764.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A02020-14cdm - 1018904922457764.pdf Tue, 29 Jul 2014 04:00:00 GMT 19 Com. v. Tisdale, C. No. 2080 EDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-S21034-14m - 1018905462457877.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S21034-14m - 1018905462457877.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S21034-14m - 1018905462457877.pdf Tue, 29 Jul 2014 04:00:00 GMT 14 Com. v. Garcia, A. No. 3503 EDA 2012 http://www.pacourts.us/assets/opinions/Superior/out/J-A09024-14m - 1018905122457813.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A09024-14m - 1018905122457813.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A09024-14m - 1018905122457813.pdf Tue, 29 Jul 2014 04:00:00 GMT 14 Tierney, K. v. Verizon Pennsylvania No. 1675 EDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-A06038-14m - 1018904492457615.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A06038-14m - 1018904492457615.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A06038-14m - 1018904492457615.pdf Tue, 29 Jul 2014 04:00:00 GMT 11 Com. v. Comfort, Z No. 3185 EDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-A15027-14m - 1018904592457668.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A15027-14m - 1018904592457668.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A15027-14m - 1018904592457668.pdf Tue, 29 Jul 2014 04:00:00 GMT 11 Com. v. Ward, W. No. 3454 EDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-S41030-14m - 1018905322457841.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S41030-14m - 1018905322457841.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S41030-14m - 1018905322457841.pdf Tue, 29 Jul 2014 04:00:00 GMT 8 In the matter of: M.A. Appeal of: M.A. No. 1450 EDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-A15013-14m - 1018904512458357.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A15013-14m - 1018904512458357.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A15013-14m - 1018904512458357.pdf Tue, 29 Jul 2014 04:00:00 GMT 7 Com. v. Dupree, N. No. 1636 EDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-A15001-14m - 1018904412457592.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A15001-14m - 1018904412457592.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A15001-14m - 1018904412457592.pdf Tue, 29 Jul 2014 04:00:00 GMT 7 In The Interest of: P.F., A Minor No. 3248 EDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-S41001-14m - 1018904612457679.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S41001-14m - 1018904612457679.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S41001-14m - 1018904612457679.pdf Tue, 29 Jul 2014 04:00:00 GMT 5 Com. v. Tart, M. No. 2510 EDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-S38015-14m - 1018905542457902.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S38015-14m - 1018905542457902.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S38015-14m - 1018905542457902.pdf Tue, 29 Jul 2014 04:00:00 GMT 2 Com. v. Tepper, F. No. 1579 EDA 2012 http://www.pacourts.us/assets/opinions/Superior/out/J-A17015-14m.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A17015-14m.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A17015-14m.pdf Tue, 29 Jul 2014 04:00:00 GMT 23 Booth, N. and T. v. AIMCO et al. No. 211 EDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-A17002-14m.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A17002-14m.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A17002-14m.pdf Tue, 29 Jul 2014 04:00:00 GMT 23 Com. v. Nesbit, D. No. 2162 MDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-A22041-14m - 1018900002456269.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A22041-14m - 1018900002456269.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A22041-14m - 1018900002456269.pdf Tue, 29 Jul 2014 04:00:00 GMT 17 J.H. v. Y.H. No. 67 MDA 2014 http://www.pacourts.us/assets/opinions/Superior/out/J-A14017-14m - 1018899872456245.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A14017-14m - 1018899872456245.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A14017-14m - 1018899872456245.pdf Tue, 29 Jul 2014 04:00:00 GMT 13 J.H. v. Y.H. No. 67 MDA 2014 http://www.pacourts.us/assets/opinions/Superior/out/J-A14017-14cdm - 1018899872456246.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A14017-14cdm - 1018899872456246.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A14017-14cdm - 1018899872456246.pdf Tue, 29 Jul 2014 04:00:00 GMT 19 Eugene, P. v. Eugene, H. No. 2254 MDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-S48003-14m - 1018900092456287.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S48003-14m - 1018900092456287.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S48003-14m - 1018900092456287.pdf Tue, 29 Jul 2014 04:00:00 GMT 8 Com. v. Monroe, R. No. 1945 MDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-S40033-14m - 1018905362457895.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S40033-14m - 1018905362457895.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S40033-14m - 1018905362457895.pdf Tue, 29 Jul 2014 04:00:00 GMT 7 Com. v. Fann, G. No. 1794 MDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-S40012-14m - 1018900172456301.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S40012-14m - 1018900172456301.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S40012-14m - 1018900172456301.pdf Tue, 29 Jul 2014 04:00:00 GMT 22 Com. v. Curry, R. No. 1273 WDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-A11019-14jo - 1018901282456701.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A11019-14jo - 1018901282456701.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A11019-14jo - 1018901282456701.pdf Tue, 29 Jul 2014 04:00:00 GMT 2 In Re: F.A.G., Appeal of: R.G. No. 2038 WDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-S24044-14m - 1018901872457119.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S24044-14m - 1018901872457119.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S24044-14m - 1018901872457119.pdf Tue, 29 Jul 2014 04:00:00 GMT 17 Com. v. Garren, K. No. 1541 WDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-S42017-14m - 1018901632456787.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S42017-14m - 1018901632456787.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S42017-14m - 1018901632456787.pdf Tue, 29 Jul 2014 04:00:00 GMT 25 Plum Property Assoc. v. Mineral Trading Co. No. 970 WDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-A16010-14m - 1018907182458300.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A16010-14m - 1018907182458300.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A16010-14m - 1018907182458300.pdf Tue, 29 Jul 2014 04:00:00 GMT 8 Com. v. Edwards, R. No. 1036 WDA 2012 http://www.pacourts.us/assets/opinions/Superior/out/J-A33002-13m - 1018901372456723.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A33002-13m - 1018901372456723.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A33002-13m - 1018901372456723.pdf Tue, 29 Jul 2014 04:00:00 GMT 7 Com. v. Mibroda, C. No. 1529 WDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-S34022-14m - 1018907472458404.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S34022-14m - 1018907472458404.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S34022-14m - 1018907472458404.pdf Tue, 29 Jul 2014 04:00:00 GMT 22 Com. v. Spence, R. No. 1669 WDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-S34025-14m - 1018901472456754.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S34025-14m - 1018901472456754.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S34025-14m - 1018901472456754.pdf Tue, 29 Jul 2014 04:00:00 GMT 22 In Re: S.M.B., Appeal of: N.C. No. 98 WDA 2014 http://www.pacourts.us/assets/opinions/Superior/out/J-S34029-14m - 1018901232456677.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S34029-14m - 1018901232456677.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S34029-14m - 1018901232456677.pdf Tue, 29 Jul 2014 04:00:00 GMT 22 Judgment Lists http://www.pacourts.us/assets/opinions/Superior/out/072814e.pdf http://www.pacourts.us/assets/opinions/Superior/out/072814e.pdf http://www.pacourts.us/assets/opinions/Superior/out/072814e.pdf Mon, 28 Jul 2014 04:00:00 GMT Judgment Lists http://www.pacourts.us/assets/opinions/Superior/out/072814m.pdf http://www.pacourts.us/assets/opinions/Superior/out/072814m.pdf http://www.pacourts.us/assets/opinions/Superior/out/072814m.pdf Mon, 28 Jul 2014 04:00:00 GMT Judgment Lists http://www.pacourts.us/assets/opinions/Superior/out/072814w.pdf http://www.pacourts.us/assets/opinions/Superior/out/072814w.pdf http://www.pacourts.us/assets/opinions/Superior/out/072814w.pdf Mon, 28 Jul 2014 04:00:00 GMT In Re: Jill B. Weintraub 1997 Trust No. 2807 EDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-A15044-14m - 1018884122451384.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A15044-14m - 1018884122451384.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A15044-14m - 1018884122451384.pdf Mon, 28 Jul 2014 04:00:00 GMT 25 Com. v. Shuler, J. No. 2175 EDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-A15031-14m - 1018889242452828.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A15031-14m - 1018889242452828.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-A15031-14m - 1018889242452828.pdf Mon, 28 Jul 2014 04:00:00 GMT 11 Com. v. White, T. No. 212 EDA 2013 http://www.pacourts.us/assets/opinions/Superior/out/J-S21010-14m - 1018884032451343.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S21010-14m - 1018884032451343.pdf http://www.pacourts.us/assets/opinions/Superior/out/J-S21010-14m - 1018884032451343.pdf Mon, 28 Jul 2014 04:00:00 GMT 9